#!/usr/bin/env python
# See COPYING file in this directory for copyright and license details.
#
# Tests the creation of an invoice, based on a packing.

import sys
import oeclient
import testconf

usage = "%s host database username password" % (sys.argv[0])
if len(sys.argv) != 5:
	print(usage)
	exit(1)

oe = oeclient.OpenERPClient()
oe.connect(sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4])

retcode = 0

t = testconf.gettestids(oe)


pids = oe.search('stock.picking', [('address_id', '=', int(t['daddr'])), ('state','=','done'), ('invoice_state', '=', '2binvoiced')])
if not pids:
	print("Could not find packing owned by test partner which is to be invoiced")
	print(" (run sendpacking test to create one)")
	retcode = 1
	exit(retcode)

# needed to intercept exception
from sys import version_info
if version_info >= (3,):
	from xmlrpc.client import Fault
else:
	from xmlrpclib import Fault
print("Creating invoice from packing %s" % (pids[0]))
try:
	oe.object_execute('stock.picking', 'action_invoice_create', [pids[0]], t['sjournal'])
	# this tries to return a dictionary, which fails due to xmlrpclib
	# see https://bugs.launchpad.net/openobject-server/+bug/689575
except Fault:
	pass

# invs won't be set, due to above bug, so search for the invoice
pname = oe.read('stock.picking', pids[0], ['name'])
invs = oe.search('account.invoice', [('origin', 'like', '%s%%' % (pname['name']))])

if not invs:
	print("Could not create invoice")
	retcode = 1
	exit(retcode)
print("Invoice created, id %s" % (invs[0]))

plineids = oe.search('stock.move', [('picking_id', '=', pids[0])])
invlineids = oe.search('account.invoice.line', [('invoice_id', '=', invs[0])])

pqs = {}
iqs = {}
for plid, ilid in zip(plineids, invlineids):
	pq = oe.read('stock.move', plid, ['product_id', 'product_qty'])
	pqs[pq['product_id'][0]] = pq['product_qty']
	iq = oe.read('account.invoice.line', ilid, ['product_id', 'quantity'])
	iqs[pq['product_id'][0]] = pq['product_qty']

if iqs.keys() == pqs.keys():
	print("Same products in picking (%s) and invoice (%s)" % (pqs.keys(), iqs.keys()))
else:
	print("Error: different products in picking (%s) and invoice (%s)" % (pqs.keys, iqs.keys))
	retcode = 1

for i in iqs.keys():
	if pqs[i] == iqs[i]:
		print("Same quantity for product id %s, %d in packing, %d in invoice" % (i, pqs[i], iqs[i]))
	else:
		print("Error: different quantity for product id %s, %d in packing, %d in invoice" % (i, pqs[i], iqs[i]))
		retcode = 1

print("Confirming invoice")
oe.exec_workflow('account.invoice', 'invoice_open', invs[0])
state = oe.read('account.invoice', invs[0], ['state'])['state']
if state == 'open':
	print("Invoice open")
else:
	print("Error: invoice is not open, it is in state %s" % (state))
	retcode = 1

exit(retcode)
