#!/usr/bin/env python
# See COPYING file in this directory for copyright and license details.
#
# Tests the creation of a purchase order.

import sys
import oeclient
import testconf

usage = "%s host database username password" % (sys.argv[0])
if len(sys.argv) != 5:
	print(usage)
	exit(1)

oe = oeclient.OpenERPClient()
oe.connect(sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4])

retcode = 0

t = testconf.gettestids(oe)


pid = oe.create('purchase.order', {'partner_id': t['partner'], 'dest_address_id': t['daddr'], 'partner_address_id': t['daddr'], 'pricelist_id': t['pricelist'], 'location_id': t['stockloc']})
print("Purchase order created, id %s" % (pid))

plid = oe.create('purchase.order.line', {'order_id': pid, 'product_id': t['prod'], 'product_uom': t['uom'], 'product_qty': t['lineqty'], 'price_unit': t['lineprice'], 'name': 'TEST LINE', 'date_planned': '2000-01-01'})
print("Order line created, id %s" % (plid))

oe.exec_workflow('purchase.order', 'purchase_confirm', pid)
state = oe.read('purchase.order', pid, ['state'])['state']
if state == 'confirmed':
	print("Purchase order confirmed")
else:
	print("Purchase order not confirmed as expected; state is %s" % (state))
	retcode = 1

pavailpre = oe.read('product.product', [t['prod']], ['virtual_available'])[0]['virtual_available']
pavailexpected = pavailpre + t['lineqty']

oe.exec_workflow('purchase.order', 'purchase_approve', pid)
state = oe.read('purchase.order', pid, ['state'])['state']
if state == 'approved':
	print("Purchase order approved")
else:
	print("Purchase order not approved as expected; state is %s" % (state))
	retcode = 1

pavailpost = oe.read('product.product', [t['prod']], ['virtual_available'])[0]['virtual_available']

if pavailpost == pavailexpected:
	print("Product available figure went up to %d as expected" % (pavailexpected))
else:
	print("Product available figure went up from %d to %d, not %d" % (pavailpre, pavailpost, pavailexpected))
	retcode = 1

exit(retcode)
