#!/usr/bin/env python
# See COPYING file in this directory for copyright and license details.
#
# Tests the creation of a sale order.

import sys
import oeclient
import testconf

usage = "%s host database username password" % (sys.argv[0])
if len(sys.argv) != 5:
	print(usage)
	exit(1)

oe = oeclient.OpenERPClient()
oe.connect(sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4])

retcode = 0

t = testconf.gettestids(oe)


oid = oe.create('sale.order', {'partner_id': t['partner'], 'partner_order_id': t['daddr'], 'partner_invoice_id': t['iaddr'], 'partner_shipping_id': t['daddr'], 'pricelist_id': t['pricelist']})
print("Order created, id %s" % (oid))

olid = oe.create('sale.order.line', {'order_id': oid, 'product_id': t['prod'], 'product_uom': t['uom'], 'product_uom_qty': t['lineqty'], 'price_unit': t['lineprice'], 'name': 'TEST LINE'})
print("Order line created, id %s" % (olid))

pavailpre = oe.read('product.product', [t['prod']], ['virtual_available'])[0]['virtual_available']
pavailexpected = pavailpre - t['lineqty']

oe.exec_workflow('sale.order', 'order_confirm', oid)
state = oe.read('sale.order', oid, ['state'])['state']
if state == 'progress':
	print("Order confirmed")
else:
	print("Order not confirmed as expected (should be 'progress'); state is %s" % (state))
	retcode = 1

pavailpost = oe.read('product.product', [t['prod']], ['virtual_available'])[0]['virtual_available']

if pavailpost == pavailexpected:
	print("Product available figure went down to %d as expected" % (pavailexpected))
else:
	print("Product available figure went down from %d to %d, not %d" % (pavailpre, pavailpost, pavailexpected))
	retcode = 1

oname = oe.read('sale.order', [oid], ['name'])
pids = oe.search('stock.picking', [('origin', '=', oname[0]['name'])])
if pids:
	print("Associated picking found, id %s" % (pids[0]))
else:
	print("No associated picking found")
	retcode = 1

exit(retcode)
