#! /usr/bin/env python
# See COPYING file in this directory for copyright and license details.
#
# Module to avoid having to use xmlrpc library directly.

from sys import version_info

if version_info >= (3,):
	from xmlrpc.client import ServerProxy
else:
	from xmlrpclib import ServerProxy

class OpenERPClient:
    common_client = None
    object_client = None
    uid = None
    password = None
    database = None
    
    def connect(self, hostname, database, username, password):
        # preserve these for future calls
        self.database = database
        self.password = password

        # some calls require the user to be logged in or strange errors amass
        self.common_client = ServerProxy("http://%s:8069/xmlrpc/common" % hostname, allow_none=True)
        self.uid = self.common_client.login(database, "admin", password)

        self.object_client = ServerProxy("http://%s:8069/xmlrpc/object" % hostname, allow_none=True)
        return self.uid

    def search(self, object, args, context={}):
        return self.object_execute(object, 'search', args, 0, None, None, context)

    def read(self, object, ids, fields, context={}):
        return self.object_execute(object, 'read', ids, fields, context)

    def create(self, object, fields):
        return self.object_execute(object, 'create', fields)

    def write(self, object, ids, fields):
        return self.object_execute(object, 'write', ids, fields)

    def unlink(self, object, ids):
        return self.object_execute(object, 'unlink', ids)

    def copy(self, object, id_, default=None):
        return self.object_execute(object, 'copy', id_, default)

    # Fixme, args should be a splat-list or whatever
    def object_execute(self, object, method, *args):
        res = self.object_client.execute(
            self.database, self.uid, self.password, object, method, *args
        )
        return res

    def exec_workflow(self, object, signal, id):
        res = self.object_client.exec_workflow(
            self.database, self.uid, self.password, object, signal, id
        )
        return res
