#!/usr/bin/env python
# See COPYING file in this directory for copyright and license details.
#
# Cancels all pickings, purchase orders, sale orders and invoices, and
# deletes cancelled purchase orders, sale orders, and invoices, which
# were created for the test partner.

import sys
import oeclient
import testconf

usage = "%s host database username password" % (sys.argv[0])
if len(sys.argv) != 5:
	print(usage)
	exit(1)

oe = oeclient.OpenERPClient()
oe.connect(sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4])

retcode = 0

t = testconf.gettestids(oe)


pids = oe.search('stock.picking', [('address_id', '=', t['daddr']), ('state', 'in', ['confirmed','assigned'])])
if not pids:
	print("No pickings found")

for pid in pids:
	oe.exec_workflow('stock.picking', 'button_cancel', pid)

states = oe.read('stock.picking', pids, ['state'])
for s in states:
	if s['state'] == 'cancel':
		print("Picking %s cancelled" % (s['id']))
		# note cancelled pickings cannot be deleted
	else:
		print("Picking %s not cancelled as expected; state is %s" % (s['id'], s['state']))
		retcode = 1


saleids = oe.search('sale.order', [('partner_id', '=', t['partner']), ('state', '=', 'progress')])
if not saleids:
	print("No sale orders found")

oe.object_execute('sale.order', 'action_cancel', saleids)

states = oe.read('sale.order', saleids, ['state'])
for s in states:
	if s['state'] == 'cancel':
		print("Sale order %s cancelled" % (s['id']))
		oe.unlink('sale.order', [s['id']])
		print("Sale order %s deleted" % (s['id']))
	else:
		print("Sale order %s not cancelled as expected; state is %s" % (s['id'], s['state']))
		retcode = 1


"""
# purchase orders aren't set to done with current tests,
# so don't bother deleting (they won't delete with done moves)
pids = oe.search('purchase.order', [('partner_id', '=', t['partner']), ('state', 'in', ['approved','except_picking','except_invoice'])])
if not pids:
	print("No purchase orders found")
print pids

oe.object_execute('purchase.order', 'action_cancel', pids)

states = oe.read('purchase.order', pids, ['state'])
for s in states:
	if s['state'] == 'cancel':
		print("Purchase order %s cancelled" % (s['id']))
		oe.unlink('purchase.order', [s['id']])
		print("Purchase order %s deleted" % (s['id']))
	else:
		print("Purchase order %s not cancelled as expected; state is %s" % (s['id'], s['state']))
		retcode = 1
"""

iids = oe.search('account.invoice', [('partner_id', '=', t['partner']), ('state', '=', 'open')])
if not iids:
	print("No invoices found")

oe.object_execute('account.invoice', 'action_cancel', iids)

states = oe.read('account.invoice', iids, ['state'])
for s in states:
	if s['state'] == 'cancel':
		print("Invoice %s cancelled" % (s['id']))
		oe.unlink('account.invoice', [s['id']])
		print("Invoice %s deleted" % (s['id']))
	else:
		print("Invoice %s not cancelled as expected; state is %s" % (s['id'], s['state']))
		retcode = 1


exit(retcode)
