#!/usr/bin/env python
# See COPYING file in this directory for copyright and license details.
#
# Tests the sending of a packing.

import sys
import oeclient
import testconf

usage = "%s host database username password" % (sys.argv[0])
if len(sys.argv) != 5:
	print(usage)
	exit(1)

oe = oeclient.OpenERPClient()
oe.connect(sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4])

retcode = 0

t = testconf.gettestids(oe)

orderids = oe.search('sale.order', [('partner_id','=',t['partner']),('state','=','progress')])
if not orderids:
	print("No sale order found; run newsaleorder.py to create one")
	exit(1)
pids = oe.read('sale.order', orderids[0], ['picking_ids'])['picking_ids']
if not orderids:
	print("No picking associated with sale order found; remove any other test sale orders and run newsaleorder.py")
	exit(1)
else:
	pid = pids[0]

oe.object_execute('stock.picking', 'action_assign', [pid])
state = oe.read('stock.picking', pid, ['state'])['state']
if state == 'assigned':
	print("Picking available")
else:
	print("Picking not available as expected; state is %s" % (state))
	retcode = 1

pqtypre = oe.read('product.product', [t['prod']], ['qty_available'])[0]['qty_available']
pqtyexpected = pqtypre - t['lineqty']

oe.exec_workflow('stock.picking', 'button_done', pid)
state = oe.read('stock.picking', pid, ['state'])['state']
if state == 'done':
	print("Picking done")
else:
	print("Picking not done as expected; state is %s" % (state))
	retcode = 1

pqtypost = oe.read('product.product', [t['prod']], ['qty_available'])[0]['qty_available']

if pqtypost == pqtyexpected:
	print("Product quantity figure went down to %d as expected" % (pqtyexpected))
else:
	print("Product quantity figure went down from %d to %d, not %d" % (pqtypre, pqtypost, pqtyexpected))
	retcode = 1

exit(retcode)
