
import xmlrpclib


class Connection(object):
    def __init__(self, server="localhost", port=8069, dbname="terp", login=None, password=None, protocol='http'):
        self.server, self.port = server, port
        self._url = "%s://%s:%s/xmlrpc/common" % (protocol, server, port)
        self._sock = xmlrpclib.ServerProxy(self._url)
        self.dbname = dbname
        self.login, self.password = login, password
        self.userid = self._sock.login(dbname, login, password)
        if not self.userid:
            raise Exception("Unable to connect to database %s using %s/%s" % (dbname, login, password))


class Database(object):
    def __init__(self, server="localhost", port=8069, supadminpass='admin'):
        self.supadminpass = supadminpass
        self.server, self.port = server, port
        self._url = "http://%s:%d/xmlrpc/db" % (server, port)
        self._sock = xmlrpclib.ServerProxy(self._url)

    def __getattr__(self, name):
        def proxy(*args, **kwargs):
            return getattr(self._sock, name)(self.supadminpass, *args, **kwargs)
        return proxy

    def list(self):
        return self._sock.list()


class Object(object):
    def __init__(self, connection, model):
        self._connection = connection
        self._model = model
        self._sock = xmlrpclib.ServerProxy("http://%s:%d/xmlrpc/object" % (connection.server, connection.port))

    def __getattr__(self, name):
        def proxy(*args, **kwargs):
            return self._sock.execute(self._connection.dbname, self._connection.userid, self._connection.password, self._model, name, *args, **kwargs)
        return proxy

    def select(self, domain, fields=None):
        ids = self.search(domain)
        return self.read(ids, fields or [])


class OpenERP_RPC_Wizard(object):
    def __init__(self, connection, name):
        self._connection = connection
        self._name = name
        self._sock = xmlrpclib.ServerProxy("http://%s:%d/xmlrpc/wizard" % (connection.server, connection.port))
        self._id = self._sock.create(self._connection.dbname, self._connection.userid, self._connection.password, self._name)

    def __getattr__(self, state):
        def proxy(**kwargs):
            return self._sock.execute(self._connection.dbname, self._connection.userid, self._connection.password, self._id, kwargs, state)
        return proxy


def demo():
    db = OpenERP_RPC_DB()
    print repr(db.list())

    cnx = OpenERP_RPC_Connection(dbname="lpot", login="admin", password="admin")
    modules = OpenERP_RPC_Object(cnx, "ir.module.module")

    ids = modules.search([('state', '=', 'installed')])
    for p in modules.read(ids, ['name']):
        print p['name']

if __name__ == '__main__':
    demo()

